package Loader::Empty;

use Moose;
with qw(Gearman::Driver::Loader);

1;
